@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #include <casacore/casa/BasicMath/Math.h>
 #include <casacore/casa/BasicSL/Constants.h>
@@ -304,6 +302,7 @@ Double roundDouble(Double val, Double ndigit) {
   // E.g. log10(0.1) gives -0.9999999, so add little number when truncating.
   Int i = Int(lgr >= 0  ?  lgr + 1.000001 : lgr - 0.000001);
   Double temp = val * pow(10.0, -i);
+  using std::round;
   return sign*round(temp)*pow(10.0, i);
 }
 
