@@ -17,21 +17,19 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #include <casacore/casa/BasicMath/Random.h>
 #include <casacore/casa/BasicSL/Constants.h>
 #include <casacore/casa/Exceptions/Error.h>
 #include <casacore/casa/Utilities/Assert.h>
 #include <casacore/casa/BasicSL/String.h>
-#include <casacore/casa/Utilities/PtrHolder.h>
 #include <casacore/casa/Arrays/Vector.h>
+#include <memory>
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
@@ -488,11 +486,11 @@ Random* Random::construct(Random::Types type, RNG* gen) {
 
 Vector<Double> Random::defaultParameters (Random::Types type) {
   MLCG gen;
-  const PtrHolder<Random> ranPtr(construct(type, &gen));
-  if (ranPtr.ptr() == 0) {
+  const std::unique_ptr<Random> ranPtr(construct(type, &gen));
+  if (!ranPtr) {
     return Vector<Double>();
   } else {
-    return ranPtr.ptr()->parameters();
+    return ranPtr->parameters();
   }
 }
 
