@@ -17,14 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//#
-//# $Id$
 
 
 #ifndef IMAGES_IMAGEFITSCONVERTER_H
@@ -36,7 +33,7 @@
 #include <casacore/casa/Arrays/IPosition.h>
 #include <casacore/casa/BasicSL/String.h>
 #include <casacore/casa/Utilities/DataType.h>
-#include <casacore/casa/Utilities/CountedPtr.h>
+#include <memory>
 
 
 #ifndef WCSLIB_GETWCSTAB
@@ -79,7 +76,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     IPosition newShape;
     IPosition cursorOrder;
     FitsKeywordList kw;
-    CountedPtr<Array<Bool> > pMask;
+    std::shared_ptr<Array<Bool>> pMask;
   };
 
 
