@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 
 #include <casacore/lattices/LEL/LatticeExprNode.h>
@@ -47,7 +45,6 @@
 #include <casacore/casa/Arrays/Array.h>
 #include <casacore/casa/Containers/Block.h>
 #include <casacore/casa/BasicSL/Constants.h>
-#include <casacore/casa/Utilities/CountedPtr.h>
 #include <casacore/casa/Utilities/Assert.h>
 #include <casacore/casa/Exceptions/Error.h> 
 #include <casacore/casa/iostream.h>
@@ -78,7 +75,7 @@ LatticeExprNode::~LatticeExprNode()
 }
 
 
-LatticeExprNode::LatticeExprNode(const CountedPtr<LELInterface<Float> >& pExpr)
+LatticeExprNode::LatticeExprNode(const std::shared_ptr<LELInterface<Float>>& pExpr)
 : donePrepare_p   (False),
   dtype_p         (TpFloat),
   isInvalid_p     (True),
@@ -86,12 +83,12 @@ LatticeExprNode::LatticeExprNode(const CountedPtr<LELInterface<Float> >& pExpr)
   pExprFloat_p    (pExpr)
 {
 #if defined(AIPS_TRACE)
-   cout << "LatticeExprNode:: constructor (CountedPtr<LELInterface<T>>&); pExpr_p.nrefs() = "
+   cout << "LatticeExprNode:: constructor (std::shared_ptr<LELInterface<T>>&); pExpr_p.nrefs() = "
 	<< pExprFloat_p.nrefs() << endl;
 #endif
 }
 
-LatticeExprNode::LatticeExprNode(const CountedPtr<LELInterface<Double> >& pExpr)
+LatticeExprNode::LatticeExprNode(const std::shared_ptr<LELInterface<Double>>& pExpr)
 : donePrepare_p   (False),
   dtype_p         (TpDouble),
   isInvalid_p     (True),
@@ -99,13 +96,13 @@ LatticeExprNode::LatticeExprNode(const CountedPtr<LELInterface<Double> >& pExpr)
   pExprDouble_p   (pExpr)
 {
 #if defined(AIPS_TRACE)
-   cout << "LatticeExprNode:: constructor (CountedPtr<LELInterface<T>>&); pExpr_p.nrefs() = "
+   cout << "LatticeExprNode:: constructor (std::shared_ptr<LELInterface<T>>&); pExpr_p.nrefs() = "
 	<< pExprDouble_p.nrefs() << endl;
 #endif
 }
 
 LatticeExprNode::LatticeExprNode
-                             (const CountedPtr<LELInterface<Complex> >& pExpr)
+                             (const std::shared_ptr<LELInterface<Complex>>& pExpr)
 : donePrepare_p   (False),
   dtype_p         (TpComplex),
   isInvalid_p     (True),
@@ -113,13 +110,13 @@ LatticeExprNode::LatticeExprNode
   pExprComplex_p  (pExpr)
 {
 #if defined(AIPS_TRACE)
-   cout << "LatticeExprNode:: constructor (CountedPtr<LELInterface<T>>&); pExpr_p.nrefs() = "
+   cout << "LatticeExprNode:: constructor (std::shared_ptr<LELInterface<T>>&); pExpr_p.nrefs() = "
 	<< pExprComplex_p.nrefs() << endl;
 #endif
 }
 
 LatticeExprNode::LatticeExprNode
-                             (const CountedPtr<LELInterface<DComplex> >& pExpr)
+                             (const std::shared_ptr<LELInterface<DComplex>>& pExpr)
 : donePrepare_p   (False),
   dtype_p         (TpDComplex),
   isInvalid_p     (True),
@@ -127,12 +124,12 @@ LatticeExprNode::LatticeExprNode
   pExprDComplex_p (pExpr)
 {
 #if defined(AIPS_TRACE)
-   cout << "LatticeExprNode:: constructor (CountedPtr<LELInterface<T>>&); pExpr_p.nrefs() = "
+   cout << "LatticeExprNode:: constructor (std::shared_ptr<LELInterface<T>>&); pExpr_p.nrefs() = "
 	<< pExprDComplex_p.nrefs() << endl;
 #endif
 }
 
-LatticeExprNode::LatticeExprNode(const CountedPtr<LELInterface<Bool> >& pExpr)
+LatticeExprNode::LatticeExprNode(const std::shared_ptr<LELInterface<Bool>>& pExpr)
 : donePrepare_p   (False),
   dtype_p         (TpBool),
   isInvalid_p     (True),
@@ -140,7 +137,7 @@ LatticeExprNode::LatticeExprNode(const CountedPtr<LELInterface<Bool> >& pExpr)
   pExprBool_p     (pExpr)
 {
 #if defined(AIPS_TRACE)
-   cout << "LatticeExprNode:: constructor (CountedPtr<LELInterface<T>>&); pExpr_p.nrefs() = "
+   cout << "LatticeExprNode:: constructor (std::shared_ptr<LELInterface<T>>&); pExpr_p.nrefs() = "
 	<< pExprBool_p.nrefs() << endl;
 #endif
 }
@@ -216,7 +213,7 @@ LatticeExprNode::LatticeExprNode (Int64 constant)
 : donePrepare_p   (False),
   dtype_p         (TpFloat),
   isInvalid_p     (False),
-  pExprFloat_p    (new LELUnaryConst<Float> (constant))
+  pExprFloat_p    (std::make_shared<LELUnaryConst<Float>>(constant))
 { 
    pAttr_p = &pExprFloat_p->getAttribute();
 
@@ -230,7 +227,7 @@ LatticeExprNode::LatticeExprNode (Int constant)
 : donePrepare_p   (False),
   dtype_p         (TpFloat),
   isInvalid_p     (False),
-  pExprFloat_p    (new LELUnaryConst<Float> (constant))
+  pExprFloat_p    (std::make_shared<LELUnaryConst<Float>>(constant))
 { 
    pAttr_p = &pExprFloat_p->getAttribute();
 
@@ -244,7 +241,7 @@ LatticeExprNode::LatticeExprNode (uInt constant)
 : donePrepare_p   (False),
   dtype_p         (TpFloat),
   isInvalid_p     (False),
-  pExprFloat_p    (new LELUnaryConst<Float> (constant))
+  pExprFloat_p    (std::make_shared<LELUnaryConst<Float>>(constant))
 { 
    pAttr_p = &pExprFloat_p->getAttribute();
 
@@ -258,7 +255,7 @@ LatticeExprNode::LatticeExprNode (Long constant)
 : donePrepare_p   (False),
   dtype_p         (TpFloat),
   isInvalid_p     (False),
-  pExprFloat_p    (new LELUnaryConst<Float> (constant))
+  pExprFloat_p    (std::make_shared<LELUnaryConst<Float>>(constant))
 { 
    pAttr_p = &pExprFloat_p->getAttribute();
 
@@ -272,7 +269,7 @@ LatticeExprNode::LatticeExprNode (Float constant)
 : donePrepare_p   (False),
   dtype_p         (TpFloat),
   isInvalid_p     (False),
-  pExprFloat_p    (new LELUnaryConst<Float> (constant))
+  pExprFloat_p    (std::make_shared<LELUnaryConst<Float>>(constant))
 { 
    pAttr_p = &pExprFloat_p->getAttribute();
 
@@ -286,7 +283,7 @@ LatticeExprNode::LatticeExprNode (Double constant)
 : donePrepare_p   (False),
   dtype_p         (TpDouble),
   isInvalid_p     (False),
-  pExprDouble_p   (new LELUnaryConst<Double> (constant))
+  pExprDouble_p   (std::make_shared<LELUnaryConst<Double>>(constant))
 { 
    pAttr_p = &pExprDouble_p->getAttribute();
 
@@ -300,7 +297,7 @@ LatticeExprNode::LatticeExprNode (const Complex& constant)
 : donePrepare_p   (False),
   dtype_p         (TpComplex),
   isInvalid_p     (False),
-  pExprComplex_p  (new LELUnaryConst<Complex> (constant))
+  pExprComplex_p  (std::make_shared<LELUnaryConst<Complex>>(constant))
 { 
    pAttr_p = &pExprComplex_p->getAttribute();
 
@@ -314,7 +311,7 @@ LatticeExprNode::LatticeExprNode (const DComplex& constant)
 : donePrepare_p   (False),
   dtype_p         (TpDComplex),
   isInvalid_p     (False),
-  pExprDComplex_p (new LELUnaryConst<DComplex> (constant))
+  pExprDComplex_p (std::make_shared<LELUnaryConst<DComplex>>(constant))
 { 
    pAttr_p = &pExprDComplex_p->getAttribute();
 
@@ -328,7 +325,7 @@ LatticeExprNode::LatticeExprNode (Bool constant)
 : donePrepare_p   (False),
   dtype_p         (TpBool),
   isInvalid_p     (False),
-  pExprBool_p     (new LELUnaryConst<Bool> (constant))
+  pExprBool_p     (std::make_shared<LELUnaryConst<Bool>>(constant))
 { 
    pAttr_p = &pExprBool_p->getAttribute();
 
@@ -353,7 +350,7 @@ LatticeExprNode::LatticeExprNode (const Lattice<Float>& lattice)
 : donePrepare_p   (False),
   dtype_p         (TpFloat),
   isInvalid_p     (False),
-  pExprFloat_p    (new LELLattice<Float> (lattice))
+  pExprFloat_p    (std::make_shared<LELLattice<Float>>(lattice))
 {
    pAttr_p = &pExprFloat_p->getAttribute();
 
@@ -367,7 +364,7 @@ LatticeExprNode::LatticeExprNode (const Lattice<Double>& lattice)
 : donePrepare_p   (False),
   dtype_p         (TpDouble),
   isInvalid_p     (False),
-  pExprDouble_p   (new LELLattice<Double> (lattice))
+  pExprDouble_p   (std::make_shared<LELLattice<Double>>(lattice))
 {
    pAttr_p = &pExprDouble_p->getAttribute();
 
@@ -381,7 +378,7 @@ LatticeExprNode::LatticeExprNode (const Lattice<Complex>& lattice)
 : donePrepare_p   (False),
   dtype_p         (TpComplex),
   isInvalid_p     (False),
-  pExprComplex_p  (new LELLattice<Complex> (lattice))
+  pExprComplex_p  (std::make_shared<LELLattice<Complex>>(lattice))
 {
    pAttr_p = &pExprComplex_p->getAttribute();
 
@@ -395,7 +392,7 @@ LatticeExprNode::LatticeExprNode (const Lattice<DComplex>& lattice)
 : donePrepare_p   (False),
   dtype_p         (TpDComplex),
   isInvalid_p     (False),
-  pExprDComplex_p (new LELLattice<DComplex> (lattice))
+  pExprDComplex_p (std::make_shared<LELLattice<DComplex>>(lattice))
 {
    pAttr_p = &pExprDComplex_p->getAttribute();
 
@@ -409,7 +406,7 @@ LatticeExprNode::LatticeExprNode (const Lattice<Bool>& lattice)
 : donePrepare_p   (False),
   dtype_p         (TpBool),
   isInvalid_p     (False),
-  pExprBool_p     (new LELLattice<Bool> (lattice))
+  pExprBool_p     (std::make_shared<LELLattice<Bool>>(lattice))
 {
    pAttr_p = &pExprBool_p->getAttribute();
 
@@ -424,7 +421,7 @@ LatticeExprNode::LatticeExprNode (const MaskedLattice<Float>& lattice)
 : donePrepare_p   (False),
   dtype_p         (TpFloat),
   isInvalid_p     (False),
-  pExprFloat_p    (new LELLattice<Float> (lattice))
+  pExprFloat_p    (std::make_shared<LELLattice<Float>>(lattice))
 {
    pAttr_p = &pExprFloat_p->getAttribute();
 
@@ -438,7 +435,7 @@ LatticeExprNode::LatticeExprNode (const MaskedLattice<Double>& lattice)
 : donePrepare_p   (False),
   dtype_p         (TpDouble),
   isInvalid_p     (False),
-  pExprDouble_p   (new LELLattice<Double> (lattice))
+  pExprDouble_p   (std::make_shared<LELLattice<Double>>(lattice))
 {
    pAttr_p = &pExprDouble_p->getAttribute();
 
@@ -452,7 +449,7 @@ LatticeExprNode::LatticeExprNode (const MaskedLattice<Complex>& lattice)
 : donePrepare_p   (False),
   dtype_p         (TpComplex),
   isInvalid_p     (False),
-  pExprComplex_p  (new LELLattice<Complex> (lattice))
+  pExprComplex_p  (std::make_shared<LELLattice<Complex>>(lattice))
 {
    pAttr_p = &pExprComplex_p->getAttribute();
 
@@ -466,7 +463,7 @@ LatticeExprNode::LatticeExprNode (const MaskedLattice<DComplex>& lattice)
 : donePrepare_p   (False),
   dtype_p         (TpDComplex),
   isInvalid_p     (False),
-  pExprDComplex_p (new LELLattice<DComplex> (lattice))
+  pExprDComplex_p (std::make_shared<LELLattice<DComplex>>(lattice))
 {
    pAttr_p = &pExprDComplex_p->getAttribute();
 
@@ -480,7 +477,7 @@ LatticeExprNode::LatticeExprNode (const MaskedLattice<Bool>& lattice)
 : donePrepare_p   (False),
   dtype_p         (TpBool),
   isInvalid_p     (False),
-  pExprBool_p     (new LELLattice<Bool> (lattice))
+  pExprBool_p     (std::make_shared<LELLattice<Bool>>(lattice))
 {
    pAttr_p = &pExprBool_p->getAttribute();
 
@@ -494,7 +491,7 @@ LatticeExprNode::LatticeExprNode (const LCRegion& region)
 : donePrepare_p   (False),
   dtype_p         (TpBool),
   isInvalid_p     (False),
-  pExprBool_p     (new LELRegion (new LattRegionHolder(region)))
+  pExprBool_p     (std::make_shared<LELRegion>(new LattRegionHolder(region)))
 {
    pAttr_p = &pExprBool_p->getAttribute();
 
@@ -508,7 +505,7 @@ LatticeExprNode::LatticeExprNode (const Slicer& slicer)
 : donePrepare_p   (False),
   dtype_p         (TpBool),
   isInvalid_p     (False),
-  pExprBool_p     (new LELRegion (new LattRegionHolder(LCSlicer(slicer))))
+  pExprBool_p     (std::make_shared<LELRegion>(new LattRegionHolder(LCSlicer(slicer))))
 {
    pAttr_p = &pExprBool_p->getAttribute();
 
@@ -522,7 +519,7 @@ LatticeExprNode::LatticeExprNode (const LattRegionHolder& region)
 : donePrepare_p   (False),
   dtype_p         (TpBool),
   isInvalid_p     (False),
-  pExprBool_p     (new LELRegion (region))
+  pExprBool_p     (std::make_shared<LELRegion>(region))
 {
    pAttr_p = &pExprBool_p->getAttribute();
 
@@ -1115,8 +1112,8 @@ LatticeExprNode sign(const LatticeExprNode& expr)
 		 AipsError);
    Block<LatticeExprNode> arg(1);
    arg[0] = expr.makeFloat();
-   LELFunctionFloat* ptr = new LELFunctionFloat(LELFunctionEnums::SIGN, arg);
-   return ptr;
+   return LatticeExprNode
+     (std::make_shared<LELFunctionFloat>(LELFunctionEnums::SIGN, arg));
 }
 
 LatticeExprNode ceil(const LatticeExprNode& expr)
@@ -1208,13 +1205,13 @@ LatticeExprNode formComplex(const LatticeExprNode& left,
    if (left.dataType()==TpFloat && right.dataType()==TpFloat) {
       arg[0] = left.makeFloat();
       arg[1] = right.makeFloat();
-      return new LELFunctionComplex (LELFunctionEnums::COMPLEX, arg);
+      return LatticeExprNode
+        (std::make_shared<LELFunctionComplex>(LELFunctionEnums::COMPLEX, arg));
    }
    arg[0] = left.makeDouble();
    arg[1] = right.makeDouble();
-   LELFunctionDComplex* ptr = new LELFunctionDComplex
-                                           (LELFunctionEnums::COMPLEX, arg);
-   return ptr;
+   return LatticeExprNode
+     (std::make_shared<LELFunctionDComplex>(LELFunctionEnums::COMPLEX, arg));
 }
 
 
@@ -1298,9 +1295,11 @@ LatticeExprNode fractile (const LatticeExprNode& expr,
    arg[1] = fraction.makeFloat();
    switch (dtype) {
    case TpFloat:
-      return new LELFunctionFloat (LELFunctionEnums::FRACTILE1D, arg);
+      return LatticeExprNode
+        (std::make_shared<LELFunctionFloat>(LELFunctionEnums::FRACTILE1D, arg));
    case TpDouble:
-      return new LELFunctionDouble (LELFunctionEnums::FRACTILE1D, arg);
+      return LatticeExprNode
+        (std::make_shared<LELFunctionDouble>(LELFunctionEnums::FRACTILE1D, arg));
    default:
       throw (AipsError ("LatticeExprNode::fractile - "
 			"Bool or complex argument used in real "
@@ -1325,9 +1324,11 @@ LatticeExprNode fractileRange (const LatticeExprNode& expr,
    arg[1] = fraction.makeFloat();
    switch (dtype) {
    case TpFloat:
-       return new LELFunctionFloat (LELFunctionEnums::FRACTILERANGE1D, arg);
+       return LatticeExprNode
+         (std::make_shared<LELFunctionFloat>(LELFunctionEnums::FRACTILERANGE1D, arg));
    case TpDouble:
-       return new LELFunctionDouble (LELFunctionEnums::FRACTILERANGE1D, arg);
+       return LatticeExprNode
+         (std::make_shared<LELFunctionDouble>(LELFunctionEnums::FRACTILERANGE1D, arg));
    default:
       throw (AipsError ("LatticeExprNode::fractileRange - "
 			"Bool or complex argument used in real "
@@ -1354,9 +1355,11 @@ LatticeExprNode fractileRange (const LatticeExprNode& expr,
    arg[2] = fraction2.makeFloat();
    switch (dtype) {
    case TpFloat:
-       return new LELFunctionFloat (LELFunctionEnums::FRACTILERANGE1D, arg);
+       return LatticeExprNode
+         (std::make_shared<LELFunctionFloat>(LELFunctionEnums::FRACTILERANGE1D, arg));
    case TpDouble:
-       return new LELFunctionDouble (LELFunctionEnums::FRACTILERANGE1D, arg);
+     return LatticeExprNode
+        (std::make_shared<LELFunctionDouble>(LELFunctionEnums::FRACTILERANGE1D, arg));
    default:
       throw (AipsError ("LatticeExprNode::fractileRange - "
 			"Bool or complex argument used in real "
@@ -1477,11 +1480,13 @@ LatticeExprNode spectralindex (const LatticeExprNode& left,
    case TpFloat:
       arg[0] = left.makeFloat();
       arg[1] = right.makeFloat();
-      return new LELSpectralIndex<Float> (arg);
+      return LatticeExprNode
+        (std::make_shared<LELSpectralIndex<Float>>(arg));
    case TpDouble:
       arg[0] = left.makeDouble();
       arg[1] = right.makeDouble();
-      return new LELSpectralIndex<Double> (arg);
+      return LatticeExprNode
+        (std::make_shared<LELSpectralIndex<Double>>(arg));
    default:
       throw (AipsError ("LatticeExprNode::spectralindex - "
 			"Bool or Complex argument used in function"));
@@ -1628,7 +1633,8 @@ LatticeExprNode operator! (const LatticeExprNode& expr)
    if (expr.isRegion()) {
       return LELRegion::makeComplement (*expr.pExprBool_p);
    }
-   return new LELUnaryBool(LELUnaryEnums::NOT, expr.pExprBool_p);
+   return LatticeExprNode
+     (std::make_shared<LELUnaryBool>(LELUnaryEnums::NOT, expr.pExprBool_p));
 }
 
 LatticeExprNode LatticeExprNode::operator[] (const LatticeExprNode& cond) const
@@ -1655,15 +1661,20 @@ LatticeExprNode LatticeExprNode::operator[] (const LatticeExprNode& cond) const
    switch (dataType()) {
    case TpBool:
       AlwaysAssert (!isRegion(), AipsError);
-      return new LELCondition<Bool> (pExprBool_p, cond.pExprBool_p);
+      return LatticeExprNode
+        (std::make_shared<LELCondition<Bool>>(pExprBool_p, cond.pExprBool_p));
    case TpFloat:
-      return new LELCondition<Float> (pExprFloat_p, cond.pExprBool_p);
+      return LatticeExprNode
+        (std::make_shared<LELCondition<Float>>(pExprFloat_p, cond.pExprBool_p));
    case TpDouble:
-      return new LELCondition<Double> (pExprDouble_p, cond.pExprBool_p);
+      return LatticeExprNode
+        (std::make_shared<LELCondition<Double>>(pExprDouble_p, cond.pExprBool_p));
    case TpComplex:
-      return new LELCondition<Complex> (pExprComplex_p, cond.pExprBool_p);
+      return LatticeExprNode
+        (std::make_shared<LELCondition<Complex>>(pExprComplex_p, cond.pExprBool_p));
    case TpDComplex:
-      return new LELCondition<DComplex> (pExprDComplex_p, cond.pExprBool_p);
+      return LatticeExprNode
+        (std::make_shared<LELCondition<DComplex>>(pExprDComplex_p, cond.pExprBool_p));
    default:
        throw (AipsError ("LatticeExprNode::operator[] - unknown datatype"));
    }
@@ -1679,8 +1690,8 @@ LatticeExprNode indexin (const LatticeExprNode& axis,
    Block<LatticeExprNode> arg(2);
    arg[0] = axis;
    arg[1] = indexFlags;
-   LELFunctionBool* ptr = new LELFunctionBool(LELFunctionEnums::INDEXIN, arg);
-   return ptr;
+   return LatticeExprNode
+     (std::make_shared<LELFunctionBool>(LELFunctionEnums::INDEXIN, arg));
 }
 
 
@@ -1690,8 +1701,8 @@ LatticeExprNode all (const LatticeExprNode& expr)
    cout << "LatticeExprNode:: 1d function all" << endl;
 #endif
    Block<LatticeExprNode> arg(1, toBool(expr));
-   LELFunctionBool* ptr = new LELFunctionBool(LELFunctionEnums::ALL, arg);
-   return ptr;
+   return LatticeExprNode
+     (std::make_shared<LELFunctionBool>(LELFunctionEnums::ALL, arg));
 }
 
 LatticeExprNode any (const LatticeExprNode& expr)
@@ -1700,8 +1711,8 @@ LatticeExprNode any (const LatticeExprNode& expr)
    cout << "LatticeExprNode:: 1d function any" << endl;
 #endif
    Block<LatticeExprNode> arg(1, toBool(expr));
-   LELFunctionBool* ptr = new LELFunctionBool(LELFunctionEnums::ANY, arg);
-   return ptr;
+   return LatticeExprNode
+     (std::make_shared<LELFunctionBool>(LELFunctionEnums::ANY, arg));
 }
 
 LatticeExprNode ntrue (const LatticeExprNode& expr)
@@ -1710,9 +1721,8 @@ LatticeExprNode ntrue (const LatticeExprNode& expr)
    cout << "LatticeExprNode:: 1d function ntrue" << endl;
 #endif
    Block<LatticeExprNode> arg(1, toBool(expr));
-   LELFunctionDouble* ptr = new LELFunctionDouble
-                                           (LELFunctionEnums::NTRUE, arg);
-   return ptr;
+   return LatticeExprNode
+     (std::make_shared<LELFunctionDouble>(LELFunctionEnums::NTRUE, arg));
 }
 
 LatticeExprNode nfalse (const LatticeExprNode& expr)
@@ -1721,9 +1731,8 @@ LatticeExprNode nfalse (const LatticeExprNode& expr)
    cout << "LatticeExprNode:: 1d function nfalse" << endl;
 #endif
    Block<LatticeExprNode> arg(1, toBool(expr));
-   LELFunctionDouble* ptr = new LELFunctionDouble
-                                           (LELFunctionEnums::NFALSE, arg);
-   return ptr;
+   return LatticeExprNode
+     (std::make_shared<LELFunctionDouble>(LELFunctionEnums::NFALSE, arg));
 }
 
 LatticeExprNode nelements(const LatticeExprNode& expr)
@@ -1735,9 +1744,8 @@ LatticeExprNode nelements(const LatticeExprNode& expr)
    if (expr.isRegion()) {
       arg[0] = toBool (expr);
    }
-   LELFunctionDouble* ptr = new LELFunctionDouble
-                                           (LELFunctionEnums::NELEM, arg);
-   return ptr;
+   return LatticeExprNode
+     (std::make_shared<LELFunctionDouble>(LELFunctionEnums::NELEM, arg));
 }
 
 LatticeExprNode ndim (const LatticeExprNode& expr)
@@ -1746,8 +1754,8 @@ LatticeExprNode ndim (const LatticeExprNode& expr)
    cout << "LatticeExprNode:: 1d function ndim" << endl;
 #endif
    Block<LatticeExprNode> arg(1, expr);
-   LELFunctionFloat* ptr = new LELFunctionFloat(LELFunctionEnums::NDIM, arg);
-   return ptr;
+   return LatticeExprNode
+     (std::make_shared<LELFunctionFloat>(LELFunctionEnums::NDIM, arg));
 }
 
 LatticeExprNode length (const LatticeExprNode& expr,
@@ -1759,8 +1767,8 @@ LatticeExprNode length (const LatticeExprNode& expr,
    Block<LatticeExprNode> arg(2);
    arg[0] = expr;
    arg[1] = axis;
-   LELFunctionFloat* ptr = new LELFunctionFloat(LELFunctionEnums::LENGTH, arg);
-   return ptr;
+   return LatticeExprNode
+     (std::make_shared<LELFunctionFloat>(LELFunctionEnums::LENGTH, arg));
 }
 
 LatticeExprNode isNaN (const LatticeExprNode& expr)
@@ -1769,8 +1777,8 @@ LatticeExprNode isNaN (const LatticeExprNode& expr)
    cout << "LatticeExprNode:: 1d function isNaN" << endl;
 #endif
    Block<LatticeExprNode> arg(1, expr);
-   LELFunctionBool* ptr = new LELFunctionBool(LELFunctionEnums::ISNAN, arg);
-   return ptr;
+   return LatticeExprNode
+     (std::make_shared<LELFunctionBool>(LELFunctionEnums::ISNAN, arg));
 }
 
 LatticeExprNode mask (const LatticeExprNode& expr)
@@ -1782,8 +1790,8 @@ LatticeExprNode mask (const LatticeExprNode& expr)
    if (expr.isRegion()) {
       arg[0] = toBool (expr);
    }
-   LELFunctionBool* ptr = new LELFunctionBool(LELFunctionEnums::MASK, arg);
-   return ptr;
+   return LatticeExprNode
+     (std::make_shared<LELFunctionBool>(LELFunctionEnums::MASK, arg));
 }
 
 LatticeExprNode value (const LatticeExprNode& expr)
@@ -1793,7 +1801,8 @@ LatticeExprNode value (const LatticeExprNode& expr)
 #endif
    if (expr.dataType() == TpBool) {
       Block<LatticeExprNode> arg(1, toBool(expr));
-      return new LELFunctionBool (LELFunctionEnums::VALUE, arg);
+      return LatticeExprNode
+        (std::make_shared<LELFunctionBool>(LELFunctionEnums::VALUE, arg));
    }
    return LatticeExprNode::newNumFunc1D (LELFunctionEnums::VALUE, expr);
 }
@@ -1814,23 +1823,28 @@ LatticeExprNode iif (const LatticeExprNode& condition,
    case TpFloat:
        arg[1] = arg1.makeFloat();
        arg[2] = arg2.makeFloat();
-       return new LELFunctionND<Float>(LELFunctionEnums::IIF, arg);
+       return LatticeExprNode
+         (std::make_shared<LELFunctionND<Float>>(LELFunctionEnums::IIF, arg));
    case TpDouble:
        arg[1] = arg1.makeDouble();
        arg[2] = arg2.makeDouble();
-       return new LELFunctionND<Double>(LELFunctionEnums::IIF, arg);
+       return LatticeExprNode
+         (std::make_shared<LELFunctionND<Double>>(LELFunctionEnums::IIF, arg));
    case TpComplex:
        arg[1] = arg1.makeComplex();
        arg[2] = arg2.makeComplex();
-       return new LELFunctionND<Complex>(LELFunctionEnums::IIF, arg);
+       return LatticeExprNode
+         (std::make_shared<LELFunctionND<Complex>>(LELFunctionEnums::IIF, arg));
    case TpDComplex:
        arg[1] = arg1.makeDComplex();
        arg[2] = arg2.makeDComplex();
-       return new LELFunctionND<DComplex>(LELFunctionEnums::IIF, arg);
+       return LatticeExprNode
+         (std::make_shared<LELFunctionND<DComplex>>(LELFunctionEnums::IIF, arg));
    case TpBool:
        arg[1] = arg1.makeBool();
        arg[2] = arg2.makeBool();
-       return new LELFunctionND<Bool>(LELFunctionEnums::IIF, arg);
+       return LatticeExprNode
+         (std::make_shared<LELFunctionND<Bool>>(LELFunctionEnums::IIF, arg));
    default:
       throw (AipsError ("LatticeExprNode::iif - unknown data type"));
    }
@@ -1850,23 +1864,28 @@ LatticeExprNode replace (const LatticeExprNode& arg1,
    case TpFloat:
        arg[0] = arg1.makeFloat();
        arg[1] = arg2.makeFloat();
-       return new LELFunctionND<Float>(LELFunctionEnums::REPLACE, arg);
+       return LatticeExprNode
+         (std::make_shared<LELFunctionND<Float>>(LELFunctionEnums::REPLACE, arg));
    case TpDouble:
        arg[0] = arg1.makeDouble();
        arg[1] = arg2.makeDouble();
-       return new LELFunctionND<Double>(LELFunctionEnums::REPLACE, arg);
+       return LatticeExprNode
+         (std::make_shared<LELFunctionND<Double>>(LELFunctionEnums::REPLACE, arg));
    case TpComplex:
        arg[0] = arg1.makeComplex();
        arg[1] = arg2.makeComplex();
-       return new LELFunctionND<Complex>(LELFunctionEnums::REPLACE, arg);
+       return LatticeExprNode
+         (std::make_shared<LELFunctionND<Complex>>(LELFunctionEnums::REPLACE, arg));
    case TpDComplex:
        arg[0] = arg1.makeDComplex();
        arg[1] = arg2.makeDComplex();
-       return new LELFunctionND<DComplex>(LELFunctionEnums::REPLACE, arg);
+       return LatticeExprNode
+         (std::make_shared<LELFunctionND<DComplex>>(LELFunctionEnums::REPLACE, arg));
    case TpBool:
        arg[0] = arg1.makeBool();
        arg[1] = arg2.makeBool();
-       return new LELFunctionND<Bool>(LELFunctionEnums::REPLACE, arg);
+       return LatticeExprNode
+         (std::make_shared<LELFunctionND<Bool>>(LELFunctionEnums::REPLACE, arg));
    default:
       throw (AipsError ("LatticeExprNode::replace - unknown data type"));
    }
@@ -1890,13 +1909,17 @@ LatticeExprNode LatticeExprNode::newNumUnary (LELUnaryEnums::Operation oper,
 {
    switch (expr.dataType()) {
    case TpFloat:
-      return new LELUnary<Float> (oper, expr.pExprFloat_p);
+      return LatticeExprNode
+        (std::make_shared<LELUnary<Float>>(oper, expr.pExprFloat_p));
    case TpDouble:
-      return new LELUnary<Double> (oper, expr.pExprDouble_p);
+      return LatticeExprNode
+        (std::make_shared<LELUnary<Double>>(oper, expr.pExprDouble_p));
    case TpComplex:
-      return new LELUnary<Complex> (oper, expr.pExprComplex_p);
+      return LatticeExprNode
+        (std::make_shared<LELUnary<Complex>>(oper, expr.pExprComplex_p));
    case TpDComplex:
-      return new LELUnary<DComplex> (oper, expr.pExprDComplex_p);
+      return LatticeExprNode
+        (std::make_shared<LELUnary<DComplex>>(oper, expr.pExprDComplex_p));
    default:
       throw (AipsError ("LatticeExprNode::newNumUnary - "
 			"Bool argument used in numerical unary operation"));
@@ -1914,15 +1937,19 @@ LatticeExprNode LatticeExprNode::newNumFunc1D (LELFunctionEnums::Function func,
 {
    switch (expr.dataType()) {
    case TpFloat:
-      return new LELFunction1D<Float> (func, expr.pExprFloat_p);
+     return LatticeExprNode
+       (std::make_shared<LELFunction1D<Float>>(func, expr.pExprFloat_p));
    case TpDouble:
-      return new LELFunction1D<Double> (func, expr.pExprDouble_p);
+     return LatticeExprNode
+       (std::make_shared<LELFunction1D<Double>>(func, expr.pExprDouble_p));
    case TpComplex:
-      return new LELFunction1D<Complex> (func, expr.pExprComplex_p);
+     return LatticeExprNode
+       (std::make_shared<LELFunction1D<Complex>>(func, expr.pExprComplex_p));
    case TpDComplex:
-      return new LELFunction1D<DComplex> (func, expr.pExprDComplex_p);
+     return LatticeExprNode
+       (std::make_shared<LELFunction1D<DComplex>>(func, expr.pExprDComplex_p));
    default:
-      throw (AipsError ("LatticeExprNode::newNumFunc1D - "
+     throw (AipsError ("LatticeExprNode::newNumFunc1D - "
 			"Bool argument used in numerical function"));
    }
    return LatticeExprNode();
@@ -1931,41 +1958,41 @@ LatticeExprNode LatticeExprNode::newNumFunc1D (LELFunctionEnums::Function func,
 
 LatticeExprNode LatticeExprNode::newRealFunc1D (LELFunctionEnums::Function func,
 						const LatticeExprNode& expr)
-//
+{
 // Create a new node for a real numerical function with 1 argument.
 // The result has the same data type as the input.
-// 
-{
    switch (expr.dataType()) {
    case TpFloat:
-      return new LELFunctionReal1D<Float> (func, expr.pExprFloat_p);
+     return LatticeExprNode
+       (std::make_shared<LELFunctionReal1D<Float>>(func, expr.pExprFloat_p));
    case TpDouble:
-      return new LELFunctionReal1D<Double> (func, expr.pExprDouble_p);
+     return LatticeExprNode
+       (std::make_shared<LELFunctionReal1D<Double>>(func, expr.pExprDouble_p));
    default:
-      throw (AipsError ("LatticeExprNode::newRealFunc1D - "
-			"Bool or complex argument used in real "
-			"numerical function"));
+     throw (AipsError ("LatticeExprNode::newRealFunc1D - "
+                       "Bool or complex argument used in real "
+                       "numerical function"));
    }
    return LatticeExprNode();
 }
 
 LatticeExprNode LatticeExprNode::newComplexFunc1D (LELFunctionEnums::Function func,
     						   const LatticeExprNode& expr)
-//
+{
 // Create a new node for a complex numerical function with 1
 // argument. The result has the same data type as the input.
-// 
-{
    Block<LatticeExprNode> arg(1);
    arg[0] = expr;
    switch (expr.dataType()) {
    case TpComplex:
-      return new LELFunctionComplex(func, arg);
+     return LatticeExprNode
+       (std::make_shared<LELFunctionComplex>(func, arg));
    case TpDComplex:
-      return new LELFunctionDComplex(func, arg);
+     return LatticeExprNode
+       (std::make_shared<LELFunctionDComplex>(func, arg));
    default:
-      throw (AipsError ("LatticeExprNode::newComplexFunc1D - "
-			"only complex arguments allowed"));
+     throw (AipsError ("LatticeExprNode::newComplexFunc1D - "
+                       "only complex arguments allowed"));
    }
    return LatticeExprNode();
 }
@@ -1983,13 +2010,15 @@ LatticeExprNode LatticeExprNode::newNumReal1D (LELFunctionEnums::Function func,
    switch (dtype) {
    case TpFloat:
    case TpComplex:
-      return new LELFunctionFloat (func, arg);
+     return  LatticeExprNode
+       (std::make_shared<LELFunctionFloat>(func, arg));
    case TpDouble:
    case TpDComplex:
-      return new LELFunctionDouble (func, arg);
+     return  LatticeExprNode
+       (std::make_shared<LELFunctionDouble>(func, arg));
    default:
-      throw (AipsError ("LatticeExprNode::newNumReal1D - "
-			"output type must be real and numeric"));
+     throw (AipsError ("LatticeExprNode::newNumReal1D - "
+                       "output type must be real and numeric"));
    }
    return LatticeExprNode();
 }
@@ -2010,24 +2039,28 @@ LatticeExprNode LatticeExprNode::newNumFunc2D (LELFunctionEnums::Function func,
    Block<LatticeExprNode> arg(2);
    switch (dtype) {
    case TpFloat:
-      arg[0] = left.makeFloat();
-      arg[1] = right.makeFloat();
-      return new LELFunctionFloat (func, arg);
+       arg[0] = left.makeFloat();
+       arg[1] = right.makeFloat();
+       return LatticeExprNode
+         (std::make_shared<LELFunctionFloat>(func, arg));
    case TpDouble:
-      arg[0] = left.makeDouble();
-      arg[1] = right.makeDouble();
-      return new LELFunctionDouble (func, arg);
+       arg[0] = left.makeDouble();
+       arg[1] = right.makeDouble();
+       return LatticeExprNode
+         (std::make_shared<LELFunctionDouble>(func, arg));
    case TpComplex:
-      arg[0] = left.makeComplex();
-      arg[1] = right.makeComplex();
-      return new LELFunctionComplex (func, arg);
+       arg[0] = left.makeComplex();
+       arg[1] = right.makeComplex();
+       return LatticeExprNode
+         (std::make_shared<LELFunctionComplex>(func, arg));
    case TpDComplex:
-      arg[0] = left.makeDComplex();
-      arg[1] = right.makeDComplex();
-      return new LELFunctionDComplex (func, arg);
+       arg[0] = left.makeDComplex();
+       arg[1] = right.makeDComplex();
+       return LatticeExprNode
+         (std::make_shared<LELFunctionDComplex>(func, arg));
    default:
-      throw (AipsError ("LatticeExprNode::newNumFunc2D - "
-			"Bool argument used in numerical function"));
+       throw (AipsError ("LatticeExprNode::newNumFunc2D - "
+                         "Bool argument used in numerical function"));
    }
    return LatticeExprNode();
 }
@@ -2069,17 +2102,21 @@ LatticeExprNode LatticeExprNode::newNumBinary (LELBinaryEnums::Operation oper,
   makeEqualDim (expr0, expr1);
   switch (dtype) {
   case TpFloat:
-    return new LELBinary<Float> (oper, expr0.pExprFloat_p,
-				 expr1.pExprFloat_p);
+    return LatticeExprNode
+      (std::make_shared<LELBinary<Float>>(oper, expr0.pExprFloat_p,
+                                          expr1.pExprFloat_p));
   case TpDouble:
-    return new LELBinary<Double> (oper, expr0.pExprDouble_p,
-				  expr1.pExprDouble_p);
+    return LatticeExprNode
+      (std::make_shared<LELBinary<Double>>(oper, expr0.pExprDouble_p,
+                                           expr1.pExprDouble_p));
   case TpComplex:
-    return new LELBinary<Complex> (oper, expr0.pExprComplex_p,
-				   expr1.pExprComplex_p);
+    return LatticeExprNode
+      (std::make_shared<LELBinary<Complex>>(oper, expr0.pExprComplex_p,
+                                            expr1.pExprComplex_p));
   default:
-    return new LELBinary<DComplex> (oper, expr0.pExprDComplex_p,
-				    expr1.pExprDComplex_p);
+    return LatticeExprNode
+      (std::make_shared<LELBinary<DComplex>>(oper, expr0.pExprDComplex_p,
+                                             expr1.pExprDComplex_p));
   }
   return LatticeExprNode();
 }
@@ -2107,8 +2144,9 @@ LatticeExprNode LatticeExprNode::newLogBinary (LELBinaryEnums::Operation oper,
   }
   // Make the operands the same dimensionality (if needed and possible).
   makeEqualDim (expr0, expr1);
-  return new LELBinaryBool (oper, expr0.pExprBool_p,
-                            expr1.pExprBool_p);
+  return LatticeExprNode
+    (std::make_shared<LELBinaryBool>(oper, expr0.pExprBool_p,
+                                     expr1.pExprBool_p));
 }
 
 
@@ -2157,20 +2195,25 @@ LatticeExprNode LatticeExprNode::newBinaryCmp (LELBinaryEnums::Operation oper,
   makeEqualDim (expr0, expr1);
   switch (dtype) {
   case TpFloat:
-    return new LELBinaryCmp<Float> (oper, expr0.pExprFloat_p,
-				    expr1.pExprFloat_p);
+    return LatticeExprNode
+      (std::make_shared<LELBinaryCmp<Float>>(oper, expr0.pExprFloat_p,
+                                             expr1.pExprFloat_p));
   case TpDouble:
-    return new LELBinaryCmp<Double> (oper, expr0.pExprDouble_p,
-				     expr1.pExprDouble_p);
+    return LatticeExprNode
+      (std::make_shared<LELBinaryCmp<Double>>(oper, expr0.pExprDouble_p,
+                                              expr1.pExprDouble_p));
   case TpComplex:
-    return new LELBinaryCmp<Complex> (oper, expr0.pExprComplex_p,
-				      expr1.pExprComplex_p);
+    return LatticeExprNode
+      (std::make_shared<LELBinaryCmp<Complex>>(oper, expr0.pExprComplex_p,
+                                               expr1.pExprComplex_p));
   case TpDComplex:
-    return new LELBinaryCmp<DComplex> (oper, expr0.pExprDComplex_p,
-				       expr1.pExprDComplex_p);
+    return LatticeExprNode
+      (std::make_shared<LELBinaryCmp<DComplex>>(oper, expr0.pExprDComplex_p,
+                                                expr1.pExprDComplex_p));
   default:
-    return new LELBinaryBool (oper, expr0.pExprBool_p,
-			      expr1.pExprBool_p);
+    return LatticeExprNode
+      (std::make_shared<LELBinaryBool>(oper, expr0.pExprBool_p,
+                                       expr1.pExprBool_p));
   }
   return LatticeExprNode();
 }
@@ -2241,74 +2284,74 @@ const IPosition& LatticeExprNode::getIPosition() const
    return iposition_p;
 }
 
-CountedPtr<LELInterface<Float> > LatticeExprNode::makeFloat() const
+std::shared_ptr<LELInterface<Float>> LatticeExprNode::makeFloat() const
 {
     switch (dataType()) {
     case TpFloat:
-	return pExprFloat_p;
+      return pExprFloat_p;
     case TpDouble:
-	return new LELConvert<Float,Double> (pExprDouble_p);
+      return std::make_shared<LELConvert<Float,Double>>(pExprDouble_p);
     default:
-	throw (AipsError ("LatticeExprNode::makeFloat - "
-			  "conversion to Float not possible"));
+      throw (AipsError ("LatticeExprNode::makeFloat - "
+                        "conversion to Float not possible"));
     }
 }
 
-CountedPtr<LELInterface<Double> > LatticeExprNode::makeDouble() const
+std::shared_ptr<LELInterface<Double>> LatticeExprNode::makeDouble() const
 {
     switch (dataType()) {
     case TpFloat:
-	return new LELConvert<Double,Float> (pExprFloat_p);
+      return std::make_shared<LELConvert<Double,Float>>(pExprFloat_p);
     case TpDouble:
-	return pExprDouble_p;
+      return pExprDouble_p;
     default:
-	throw (AipsError ("LatticeExprNode::makeDouble - "
-			  "conversion to Double not possible"));
+      throw (AipsError ("LatticeExprNode::makeDouble - "
+                        "conversion to Double not possible"));
     }
 }
 
-CountedPtr<LELInterface<Complex> > LatticeExprNode::makeComplex() const
+std::shared_ptr<LELInterface<Complex>> LatticeExprNode::makeComplex() const
 {
     switch (dataType()) {
     case TpFloat:
-	return new LELConvert<Complex,Float> (pExprFloat_p);
+      return std::make_shared<LELConvert<Complex,Float>>(pExprFloat_p);
     case TpDouble:
-	return new LELConvert<Complex,Double> (pExprDouble_p);
+      return std::make_shared<LELConvert<Complex,Double>>(pExprDouble_p);
     case TpComplex:
-	return pExprComplex_p;
+      return pExprComplex_p;
     case TpDComplex:
-	return new LELConvert<Complex,DComplex> (pExprDComplex_p);
+      return std::make_shared<LELConvert<Complex,DComplex>>(pExprDComplex_p);
     default:
-	throw (AipsError ("LatticeExprNode::makeComplex - "
-			  "conversion to Complex not possible"));
+      throw (AipsError ("LatticeExprNode::makeComplex - "
+                        "conversion to Complex not possible"));
     }
 }
 
-CountedPtr<LELInterface<DComplex> > LatticeExprNode::makeDComplex() const
+std::shared_ptr<LELInterface<DComplex>> LatticeExprNode::makeDComplex() const
 {
     switch (dataType()) {
     case TpFloat:
-	return new LELConvert<DComplex,Float> (pExprFloat_p);
+      return std::make_shared<LELConvert<DComplex,Float>>(pExprFloat_p);
     case TpDouble:
-	return new LELConvert<DComplex,Double> (pExprDouble_p);
+      return std::make_shared<LELConvert<DComplex,Double>>(pExprDouble_p);
     case TpComplex:
-	return new LELConvert<DComplex,Complex> (pExprComplex_p);
+      return std::make_shared<LELConvert<DComplex,Complex>>(pExprComplex_p);
     case TpDComplex:
-	return pExprDComplex_p;
+      return pExprDComplex_p;
     default:
-	throw (AipsError ("LatticeExprNode::makeDComplex - "
-			  "conversion to DComplex not possible"));
+      throw (AipsError ("LatticeExprNode::makeDComplex - "
+                        "conversion to DComplex not possible"));
     }
 }
 
-CountedPtr<LELInterface<Bool> > LatticeExprNode::makeBool() const
+std::shared_ptr<LELInterface<Bool>> LatticeExprNode::makeBool() const
 {
     if (dataType() != TpBool) {
-	throw (AipsError ("LatticeExprNode::makeBool - "
-			  "conversion to Bool not possible"));
+      throw (AipsError ("LatticeExprNode::makeBool - "
+                        "conversion to Bool not possible"));
     }
     if (isRegion()) {
-        return new LELRegionAsBool ((const LELRegion&)(*pExprBool_p));
+      return std::make_shared<LELRegionAsBool>(dynamic_cast<LELRegion&>(*pExprBool_p));
     }
     return pExprBool_p;
 }
@@ -2346,4 +2389,3 @@ Int LatticeExprNode::makeEqualDim (LatticeExprNode& expr0,
 }
 
 } //# NAMESPACE CASACORE - END
-
