@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 //# Includes
 #include <casacore/measures/Measures/Nutation.h>
@@ -218,7 +216,7 @@ void Nutation::calcNut(Double time, Bool calcDer) {
         for (uInt i=0; i<5; i++) {
           fa(i) = MeasTable::fundArg1950(i+1)(t);
         }
-        CountedPtr<Matrix<Double> > mul(MeasTable::mulSC1950(t, 1e-6));
+        std::shared_ptr<Matrix<Double>> mul(MeasTable::mulSC1950(t, 1e-6));
         for (uInt i=0; i<69; i++) {
           dtmp = 0;
           for (uInt j=0; j<5; j++) {
@@ -235,7 +233,7 @@ void Nutation::calcNut(Double time, Bool calcDer) {
         for (uInt i=0; i<5; i++) {
           fa(i) = MeasTable::fundArg2000(i+1)(t);
         }
-        CountedPtr<Matrix<Double> > mul(MeasTable::mulSC2000B(t, 1e-6));
+        std::shared_ptr<Matrix<Double>> mul(MeasTable::mulSC2000B(t, 1e-6));
         for (Int i=76; i>=0; --i) {
           dtmp = 0;
           for (uInt j=0; j<5; j++) {
@@ -257,7 +255,7 @@ void Nutation::calcNut(Double time, Bool calcDer) {
         for (uInt i=0; i<5; i++) {
           fa(i) = MeasTable::fundArg2000(i+1)(t);
         }
-        CountedPtr<Matrix<Double> > mul(MeasTable::mulSC2000A(t, 1e-6));
+        std::shared_ptr<Matrix<Double>> mul(MeasTable::mulSC2000A(t, 1e-6));
         for (Int i=677; i>=0; --i) {
           dtmp = 0;
           for (uInt j=0; j<5; j++) {
@@ -296,7 +294,7 @@ void Nutation::calcNut(Double time, Bool calcDer) {
 	for (uInt i=0; i<5; i++) {
 	  fa(i) = MeasTable::fundArg(i+1)(t);
 	}
-        CountedPtr<Matrix<Double> > mul(MeasTable::mulSC(t, 1e-6));
+        std::shared_ptr<Matrix<Double>> mul(MeasTable::mulSC(t, 1e-6));
 	for (uInt i=0; i<106; i++) {
 	  dtmp = 0;
 	  for (uInt j=0; j<5; j++) {
@@ -376,7 +374,7 @@ void Nutation::calcNut(Double time, Bool calcDer) {
           fa(i) = MeasTable::fundArg1950(i+1)(t);
           dfa(i) = (MeasTable::fundArg1950(i+1).derivative())(t);
         }
-        CountedPtr<Matrix<Double> > mul(MeasTable::mulSC1950(t, 1e-6));
+        std::shared_ptr<Matrix<Double>> mul(MeasTable::mulSC1950(t, 1e-6));
         for (uInt i=0; i<69; i++) {
           dtmp = ddtmp = 0;
           for (uInt j=0; j<5; j++) {
@@ -395,7 +393,7 @@ void Nutation::calcNut(Double time, Bool calcDer) {
           fa(i) = MeasTable::fundArg2000(i+1)(t);
           dfa(i) = (MeasTable::fundArg2000(i+1).derivative())(t);
         }
-        CountedPtr<Matrix<Double> > mul(MeasTable::mulSC2000B(t, 1e-6));
+        std::shared_ptr<Matrix<Double>> mul(MeasTable::mulSC2000B(t, 1e-6));
         for (Int i=76; i>=0; --i) {
           dtmp = ddtmp = 0;
           for (uInt j=0; j<5; j++) {
@@ -415,7 +413,7 @@ void Nutation::calcNut(Double time, Bool calcDer) {
           fa(i) = MeasTable::fundArg2000(i+1)(t);
           dfa(i) = (MeasTable::fundArg2000(i+1).derivative())(t);
         }
-        CountedPtr<Matrix<Double> > mul(MeasTable::mulSC2000A(t, 1e-6));
+        std::shared_ptr<Matrix<Double>> mul(MeasTable::mulSC2000A(t, 1e-6));
         for (Int i=677; i>=0; --i) {
           dtmp = ddtmp = 0;
           for (uInt j=0; j<5; j++) {
@@ -456,7 +454,7 @@ void Nutation::calcNut(Double time, Bool calcDer) {
 	  fa(i) = MeasTable::fundArg(i+1)(t);
 	  dfa(i) = (MeasTable::fundArg(i+1).derivative())(t);
 	}
-        CountedPtr<Matrix<Double> > mul(MeasTable::mulSC(t, 1e-6));
+        std::shared_ptr<Matrix<Double>> mul(MeasTable::mulSC(t, 1e-6));
 	for (uInt i=0; i<106; i++) {
 	  dtmp = ddtmp = 0;
 	  for (uInt j=0; j<5; j++) {
