@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 //# Includes
 #include <casacore/ms/MSOper/NewMSSimulator.h>
@@ -71,7 +69,6 @@
 #include <casacore/measures/Measures/MeasData.h>
 #include <casacore/measures/Measures/MFrequency.h>
 #include <casacore/measures/Measures.h>
-#include <casacore/casa/Utilities/CountedPtr.h>
 #include <casacore/casa/Utilities/Assert.h>
 #include <casacore/casa/Arrays/ArrayUtil.h>
 #include <casacore/casa/Arrays/Slicer.h>
@@ -105,7 +102,7 @@ const String flagTileId = "FLAG_CATEGORY_HYPERCUBE_ID";
 struct MSFeedParameterExtractor : protected MSIter {
   
   MSFeedParameterExtractor(const MeasurementSet &ms) {
-      msc_p=new MSColumns(ms);
+      msc_p.reset (new MSColumns(ms));
       msc_p->antenna().mount().getColumn(antennaMounts_p,True);
       checkFeed_p=True;
       setFeedInfo();
@@ -140,7 +137,7 @@ void NewMSSimulator::defaults() {
 }
   
 NewMSSimulator::NewMSSimulator(const String& MSName) :
-  ms_p(0), dataAcc_p(), scratchDataAcc_p(), sigmaAcc_p(), flagAcc_p(),
+  dataAcc_p(), scratchDataAcc_p(), sigmaAcc_p(), flagAcc_p(),
   maxData_p(2e9)
 {
   LogIO os(LogOrigin("NewMSSimulator", "NewMSSimulator<const String& MSName)", WHERE));
@@ -288,7 +285,7 @@ NewMSSimulator::NewMSSimulator(const String& MSName) :
   }
 
   // Now we can create the MeasurementSet and add the (empty) subtables
-  ms_p = casacore::CountedPtr<MeasurementSet>(new MeasurementSet(newMS,0));
+  ms_p.reset (new MeasurementSet(newMS,0));
   ms_p->createDefaultSubtables(Table::New);
 
   // add the SOURCE table  [copied from SimpleSimulator]
@@ -343,14 +340,14 @@ NewMSSimulator::NewMSSimulator(const String& MSName) :
 }
 
 NewMSSimulator::NewMSSimulator(MeasurementSet& theMS) :
-  ms_p(0), dataAcc_p(), scratchDataAcc_p(), sigmaAcc_p(), flagAcc_p(),
+  dataAcc_p(), scratchDataAcc_p(), sigmaAcc_p(), flagAcc_p(),
   maxData_p(2e9)
 {
   LogIO os(LogOrigin("NewMSSimulator", "NewMSSimulator(MeasurementSet& theMS)", WHERE));
 
   defaults();
 
-  ms_p = casacore::CountedPtr<MeasurementSet>(new MeasurementSet(theMS));
+  ms_p.reset (new MeasurementSet(theMS));
 
   os << "Opening MeasurementSet " << ms_p->tableName() << " with " << ms_p->nrow() << " rows" << LogIO::POST;
   dataWritten_p=ms_p->nrow();
@@ -694,7 +691,7 @@ void NewMSSimulator::initFields(const String& sourceName,
 
 }
 
-casacore::CountedPtr<MeasurementSet>
+std::shared_ptr<MeasurementSet>
 NewMSSimulator::getMs () const
 {
     return ms_p;
