@@ -17,13 +17,11 @@
 //# 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id: readms.cc 21451 2014-06-10 07:48:08Z gervandiepen $
 
 //# Includes
 
@@ -260,8 +258,8 @@ void showParms()
                      TableIterator::NoSort);
   Table tab1 = iter.table();
   Int64 ntime  = ms.nrow() / tab1.nrow();
-  Int64 nspw   = Table(tableCommand("select unique DATA_DESC_ID from $1", tab1)).nrow();
-  Int64 nbl    = Table(tableCommand("select unique ANTENNA1,ANTENNA2 from $1", tab1)).nrow();
+  Int64 nspw   = tableCommand("select unique DATA_DESC_ID from $1", tab1).table().nrow();
+  Int64 nbl    = tableCommand("select unique ANTENNA1,ANTENNA2 from $1", tab1).table().nrow();
   Int64 nant   = ms.antenna().nrow();
   Int64 nfield = ms.field().nrow();
   Int64 ntimefield = 0;
@@ -575,10 +573,10 @@ void setTSMCacheSize (const Table& tab, const String& columnName,
   }
 }
 
-void readRowsHDF5 (const CountedPtr<HDF5DataSet>& hflag,
-                   const CountedPtr<HDF5DataSet>& hdata,
-                   const CountedPtr<HDF5DataSet>& hfloatdata,
-                   const CountedPtr<HDF5DataSet>& hweight,
+void readRowsHDF5 (const std::shared_ptr<HDF5DataSet>& hflag,
+                   const std::shared_ptr<HDF5DataSet>& hdata,
+                   const std::shared_ptr<HDF5DataSet>& hfloatdata,
+                   const std::shared_ptr<HDF5DataSet>& hweight,
                    Int64 row,
                    Int64 nrow)
 {
@@ -633,10 +631,10 @@ void readRowsHDF5 (const CountedPtr<HDF5DataSet>& hflag,
   }
 }
 
-void readRowsHDF5 (const CountedPtr<HDF5DataSet>& hflag,
-                   const CountedPtr<HDF5DataSet>& hdata,
-                   const CountedPtr<HDF5DataSet>& hfloatdata,
-                   const CountedPtr<HDF5DataSet>& hweight,
+void readRowsHDF5 (const std::shared_ptr<HDF5DataSet>& hflag,
+                   const std::shared_ptr<HDF5DataSet>& hdata,
+                   const std::shared_ptr<HDF5DataSet>& hfloatdata,
+                   const std::shared_ptr<HDF5DataSet>& hweight,
                    const Slicer& slicer)
 {
   IPosition shp(slicer.length());
@@ -691,10 +689,10 @@ void readRowsHDF5 (const CountedPtr<HDF5DataSet>& hflag,
   }
 }
 
-Int64 readStepsHDF5 (const CountedPtr<HDF5DataSet>& hflag,
-                     const CountedPtr<HDF5DataSet>& hdata,
-                     const CountedPtr<HDF5DataSet>& hfloatdata,
-                     const CountedPtr<HDF5DataSet>& hweightspectrum,
+Int64 readStepsHDF5 (const std::shared_ptr<HDF5DataSet>& hflag,
+                     const std::shared_ptr<HDF5DataSet>& hdata,
+                     const std::shared_ptr<HDF5DataSet>& hfloatdata,
+                     const std::shared_ptr<HDF5DataSet>& hweightspectrum,
                      Int64 nrow,
                      Int64& niter)
 {
@@ -746,11 +744,10 @@ std::vector<Int64> doHDF5 (int seqnr, const String& name)
     HDF5Group hspw(hfile, groupNames[i]);
     // Get the attributes.
     Record attr (HDF5Record::readRecord (hspw, "ATTR"));
-    CountedPtr<HDF5DataSet> hdata;
-    CountedPtr<HDF5DataSet> hfloatdata;
-    CountedPtr<HDF5DataSet> hflag;
-    CountedPtr<HDF5DataSet> hweightspectrum;
-    hflag = new HDF5DataSet (hspw, "FLAG", (Bool*)0);
+    std::shared_ptr<HDF5DataSet> hdata;
+    std::shared_ptr<HDF5DataSet> hfloatdata;
+    std::shared_ptr<HDF5DataSet> hweightspectrum;
+    std::shared_ptr<HDF5DataSet> hflag = std::make_shared<HDF5DataSet>(hspw, "FLAG", (Bool*)0);
     IPosition shape = hflag->shape();
     IPosition tileShape = hflag->tileShape();
     uInt tileSize = 0;
@@ -759,7 +756,7 @@ std::vector<Int64> doHDF5 (int seqnr, const String& name)
       hflag->setCacheSize (myCacheSizeFlag==0 ? cacheSize:myCacheSizeFlag);
     }
     try {
-      hdata = new HDF5DataSet (hspw, "DATA", (Complex*)0);
+      hdata = std::make_shared<HDF5DataSet>(hspw, "DATA", (Complex*)0);
       tileShape = hdata->tileShape();
       if (myReadData) {
         hdata->setCacheSize (myCacheSizeData==0 ? cacheSize:myCacheSizeData);
@@ -771,7 +768,7 @@ std::vector<Int64> doHDF5 (int seqnr, const String& name)
     }
     if (! myReadData) {
       try {
-        hfloatdata = new HDF5DataSet (hspw, "FLOAT_DATA", (Complex*)0);
+        hfloatdata = std::make_shared<HDF5DataSet>(hspw, "FLOAT_DATA", (Complex*)0);
         tileShape = hdata->tileShape();
         if (myReadFloatData) {
           hfloatdata->setCacheSize (myCacheSizeData==0 ? cacheSize:myCacheSizeData);
@@ -782,7 +779,7 @@ std::vector<Int64> doHDF5 (int seqnr, const String& name)
       }
     }
     if (myReadWeightSpectrum) {
-      hweightspectrum = new HDF5DataSet (hspw, "WEIGHT_SPECTRUM", (float*)0);
+      hweightspectrum = std::make_shared<HDF5DataSet>(hspw, "WEIGHT_SPECTRUM", (float*)0);
       hweightspectrum->setCacheSize (myCacheSizeWeight==0 ? cacheSize:myCacheSizeWeight);
     }
     // Show some parms for the very first spw.
