@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id: 
 //----------------------------------------------------------------------------
 
 #include <casacore/msfits/MSFits/MSFitsIDI.h>
@@ -292,12 +290,14 @@ void MSFitsIDI::readFITSFile(Bool& atEnd)
 
   // Correlator
   String correlat;
+  Float corVer = 0.0;
+  Float vanVleck = 0.0;
 
   // Loop over all HDU in the FITS-IDI file
   Bool initFirstMain = True;
   while (infits.err() == FitsIO::OK && !infits.eof()) {
 
-    // Fetch correlator name from the primary HDU
+    // Fetch correlator info from the primary HDU
     if (infits.hdutype() == FITS::PrimaryArrayHDU) {
       BytePrimaryArray tab(infits);
       if (tab.kw("CORRELAT")) {
@@ -305,6 +305,14 @@ void MSFitsIDI::readFITSFile(Bool& atEnd)
 	correlat.trim();
 	os << LogIO::NORMAL << "Correlator: " << correlat << LogIO::POST;
       }
+      if(tab.kw("FXCORVER")){
+	corVer = std::stof(tab.kw("FXCORVER")->asString());
+	os << LogIO::NORMAL << "CorVer: " << corVer << LogIO::POST;
+      }
+      if (tab.kw("VANVLECK")) {
+	vanVleck = tab.kw("VANVLECK")->asFloat();
+	os << LogIO::NORMAL << "VanVleck: " << vanVleck << LogIO::POST;
+      }
     }
 
     // Skip non-binary table HDU's
@@ -318,7 +326,8 @@ void MSFitsIDI::readFITSFile(Bool& atEnd)
 
     } else {
       // Process the FITS-IDI input from the position of this binary table
-      FITSIDItoMS1 bintab(infits, correlat, itsObsType, initFirstMain);
+      FITSIDItoMS1 bintab(infits, correlat, itsObsType, initFirstMain,
+			  vanVleck, corVer);
       initFirstMain = False;
       String hduName = bintab.extname();
       hduName = hduName.before(trailing);
@@ -415,6 +424,16 @@ void MSFitsIDI::readFITSFile(Bool& atEnd)
       mssub.rename (itsMSOut+"/GAIN_CURVE",Table::New);
       msmain.rwKeywordSet().defineTable("GAIN_CURVE",mssub);
     }
+    if (subTableName(isub)=="PHASE-CAL") {
+      Table mssub(itsMSOut+"_tmp/"+subTableName(isub)+"/PHASE_CAL",Table::Update);
+      mssub.rename (itsMSOut+"/PHASE_CAL",Table::New);
+      msmain.rwKeywordSet().defineTable("PHASE_CAL",mssub);
+    }
+    if (subTableName(isub)=="CALC") {
+      Table mssub(itsMSOut+"_tmp/"+subTableName(isub)+"/EARTH_ORIENTATION",Table::Update);
+      mssub.rename (itsMSOut+"/EARTH_ORIENTATION",Table::New);
+      msmain.rwKeywordSet().defineTable("EARTH_ORIENTATION",mssub);
+    }
     //if (subTableName(isub)=="INTERFEROMETER_MODEL") {
     //  Table mssub(itsMSOut+"_tmp/"+subTableName(isub)+"/IDI_CORRELATOR_MODEL",Table::Update);
     //  mssub.rename (itsMSOut+"/IDI_CORRELATOR_MODEL",Table::Update);
