@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #ifndef TABLES_TILEDFILEACCESS_H
 #define TABLES_TILEDFILEACCESS_H
@@ -112,6 +110,12 @@ public:
 
   ~TiledFileAccess();
 
+  // Forbid copy constructor.
+  TiledFileAccess (const TiledFileAccess&) = delete;
+
+  // Forbid assignment.
+  TiledFileAccess& operator= (const TiledFileAccess&) = delete;
+
   // Is the file writable?
   Bool isWritable() const
     { return itsWritable; }
@@ -239,13 +243,6 @@ public:
 
 
 private:
-  // Forbid copy constructor and assignment.
-  // <group>
-  TiledFileAccess (const TiledFileAccess&);
-  TiledFileAccess& operator= (const TiledFileAccess&);
-  // </group>
-
-
   TSMCube*         itsCube;
   TiledFileHelper* itsTSM;
   uInt             itsLocalPixelSize;
