@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #ifndef TABLES_VSCENGINE_H
 #define TABLES_VSCENGINE_H
@@ -153,6 +151,9 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 //      virtual ~AVSCEngine()
 //      {}
 //
+//      // Assignment is not needed and therefore forbidden.
+//      AVSCEngine& operator= (const AVSCEngine&) = delete;
+//
 //      // Clone the object.
 //      virtual DataManager* clone() const
 //      {
@@ -214,10 +215,6 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 //        yTargetName_p (that.yTargetName_p)
 //      {}
 //
-//      // Assignment is not needed and therefore forbidden
-//      // (so it is made private and is not implemented).
-//      AVSCEngine& operator= (const AVSCEngine&);
-//
 //
 //      // The target column names.
 //      String xTargetName_p;
@@ -306,6 +303,9 @@ public:
     // Destructor is mandatory.
     ~VSCEngine();
 
+    // Assignment is not needed and therefore forbidden.
+    VSCEngine<T>& operator= (const VSCEngine<T>&) = delete;
+
     // Return the data manager type name.
     // This defaults to the data type ID followed by VSCEngine
     // (meaning Virtual Scalar Column Engine).
@@ -316,16 +316,11 @@ public:
 	{ return sourceName_p; }
 
 protected:
-
     // Copy constructor is only used by clone().
     // (so it is made protected).
     VSCEngine (const VSCEngine<T>&);
 
 private:
-    // Assignment is not needed and therefore forbidden
-    // (so it is made private).
-    VSCEngine<T>& operator= (const VSCEngine<T>&);
-
     // The column is in principle writable.
     // This does not mean it is actually writable, because that
     // depends on the fact if the table is writable.
