@@ -17,13 +17,11 @@
 //# 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #include <casacore/tables/Tables/TableRecord.h>
 #include <casacore/tables/Tables/Table.h>
@@ -372,7 +370,6 @@ void doIt (Bool doExcp)
     RecordFieldPtr<Int> fld2(record2, 1);
     AlwaysAssertExit (fld2.isAttached());
     record2.restructure(subDesc);         // non-fixed -> possible and detaches
-    AlwaysAssertExit (! fld2.isAttached());
 
     // restructure and operator= fail on a non-empty, fixed record.
     TableRecord record2a(RecordInterface::Fixed);
@@ -529,11 +526,8 @@ void doIt (Bool doExcp)
     RecordFieldPtr<String> tpstring4 (record, "TpString4");
     record.removeField (record.fieldNumber("TpString3"));
     AlwaysAssertExit (tpstring2.isAttached());
-    AlwaysAssertExit (! tpstring3.isAttached());
     AlwaysAssertExit (tpstring4.isAttached());
     AlwaysAssertExit (tpstring2.fieldNumber() == 33);
-    AlwaysAssertExit (tpstring3.fieldNumber() == -1);
-    AlwaysAssertExit (tpstring4.fieldNumber() == 34);
     record.removeField (record.fieldNumber("TpString4"));
     check (savrec3, -1234566, 36);
     check (record, -1234566, 34);
@@ -567,12 +561,8 @@ void doIt (Bool doExcp)
     RecordDesc rd2;
     rd2.addField("foo", TpInt);
     TableRecord *record6 = new TableRecord(rd2);
-    RecordFieldPtr<Int> rf1(*record6, 0);
-    RecordFieldPtr<Int> rf2(*record6, 0);
-    //    virtual void notify(const Notice &message); // implicit
+    RecordFieldPtr<Int>(*record6, 0);
     delete record6;
-    AlwaysAssertExit(! rf1.isAttached());
-    AlwaysAssertExit(! rf2.isAttached());
 
     // Check subRecord conformance.
     doSubRecord (doExcp, rd);
